@@ -31,7 +31,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.8.2';
+our $VERSION = '3.9.0';
 
 =head1 SYNOPSIS
 
@@ -994,7 +994,15 @@ sub get_streaming_urls {
         my $caption_data  = $self->parse_json_string($captions_json);
 
         if (eval { ref($caption_data->{captions}{playerCaptionsTracklistRenderer}{captionTracks}) eq 'ARRAY' }) {
+
             push @caption_urls, @{$caption_data->{captions}{playerCaptionsTracklistRenderer}{captionTracks}};
+
+            my $translationLanguages = $caption_data->{captions}{playerCaptionsTracklistRenderer}{translationLanguages};
+            if (ref($translationLanguages) eq 'ARRAY') {
+                foreach my $caption (@caption_urls) {
+                    $caption->{translationLanguages} = $translationLanguages;
+                }
+            }
         }
     }
 
